import { MagicalClass } from 'js-magic';
import { AxiosInstance } from 'axios';
import { IRequestResponse, APIHandlerConfig, EndpointConfig } from './types/http-request-handler';
import { HttpRequestHandler } from './http-request-handler';
/**
 * Handles dispatching of API requests
 */
export declare class ApiHandler implements MagicalClass {
    /**
     * TS Index signature
     */
    [x: string]: any;
    /**
     * Api Url
     */
    apiUrl: string;
    /**
     * @var httpRequestHandler Request Wrapper Instance
     */
    httpRequestHandler: HttpRequestHandler;
    /**
     * Endpoints
     */
    apiEndpoints: Record<string, EndpointConfig>;
    /**
     * Logger
     */
    logger: any;
    /**
     * Creates an instance of API Handler
     *
     * @param {string} apiUrl               Base URL for all API calls
     * @param {number} timeout              Request timeout
     * @param {string} strategy             Error Handling Strategy
     * @param {string} flattenResponse      Whether to flatten response "data" object within "data" one
     * @param {*} logger                    Instance of Logger Class
     * @param {*} onError                   Instance of Error Service Class
     */
    constructor({ apiUrl, apiEndpoints, timeout, cancellable, strategy, flattenResponse, defaultResponse, logger, onError, ...config }: APIHandlerConfig);
    /**
     * Get Provider Instance
     *
     * @returns {AxiosInstance} Provider's instance
     */
    getInstance(): AxiosInstance;
    /**
     * Maps all API requests
     *
     * @param {*} prop          Caller
     * @returns {Function}      Tailored request function
     */
    __get(prop: any): any;
    /**
     * Handle Single API Request
     *
     * @param {*} args      Arguments
     * @returns {Promise}   Resolvable API provider promise
     */
    handleRequest(...args: any): Promise<IRequestResponse>;
    /**
     * Triggered when trying to use non-existent endpoints
     *
     * @param prop Method Name
     * @returns {Promise}
     */
    protected handleNonImplemented(prop: string): Promise<any>;
}
export declare const createApiFetcher: (options: APIHandlerConfig) => ApiHandler;
